from promptlayer.promptlayer import PromptLayerBase
import promptlayer.langchain as langchain
import openai
import os

api_key = os.environ.get("PROMPTLAYER_API_KEY")
openai = PromptLayerBase(openai, function_name="openai")


__all__ = [
    "api_key",
    "openai",
]
